@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2021-2022 Greenbone Networks GmbH
+# Copyright (C) 2021-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -21,7 +21,7 @@ from enum import Enum
 from typing import Any, Optional
 
 from gvm.errors import InvalidArgument, RequiredArgument
-from gvm.utils import add_filter
+from gvm.utils import add_filter, to_bool
 from gvm.xml import XmlCommand
 
 
@@ -101,12 +101,14 @@ class HostsMixin:
         *,
         filter_string: Optional[str] = None,
         filter_id: Optional[str] = None,
+        details: Optional[bool] = None,
     ) -> Any:
         """Request a list of hosts
 
         Arguments:
             filter_string: Filter term to use for the query
             filter_id: UUID of an existing filter to use for the query
+            details: Whether to include additional information (e.g. tags)
 
         Returns:
             The response. See :py:meth:`send_command` for details.
@@ -118,13 +120,17 @@ class HostsMixin:
 
         add_filter(cmd, filter_string, filter_id)
 
+        if details is not None:
+            cmd.set_attribute("details", to_bool(details))
+
         return self._send_xml_command(cmd)
 
-    def get_host(self, host_id: str) -> Any:
+    def get_host(self, host_id: str, *, details: Optional[bool] = None) -> Any:
         """Request a single host
 
         Arguments:
             host_id: UUID of an existing host
+            details: Whether to include additional information (e.g. tags)
 
         Returns:
             The response. See :py:meth:`send_command` for details.
@@ -139,6 +145,9 @@ class HostsMixin:
         cmd.set_attribute("asset_id", host_id)
         cmd.set_attribute("type", "host")
 
+        if details is not None:
+            cmd.set_attribute("details", to_bool(details))
+
         return self._send_xml_command(cmd)
 
     def modify_host(
