@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2020-2022 Greenbone Networks GmbH
+# Copyright (C) 2020-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -73,12 +73,17 @@ class SSHConnectionTestCase(unittest.TestCase):
         )
 
     def test_connect_error(self):
-        print(self.known_hosts_file.read_text(encoding="utf-8"))
-
         ssh_connection = SSHConnection(known_hosts_file=self.known_hosts_file)
         with self.assertRaises(GvmError, msg="SSH Connection failed"):
             ssh_connection.connect()
 
+    def test_connect_error_auto_accept_host(self):
+        ssh_connection = SSHConnection(
+            known_hosts_file=self.known_hosts_file, auto_accept_host=True
+        )
+        with self.assertRaises(GvmError, msg="SSH Connection failed"):
+            ssh_connection.connect()
+
     def test_connect(self):
         with patch("paramiko.SSHClient") as SSHClientMock:
             client_mock = SSHClientMock.return_value
@@ -93,9 +98,25 @@ class SSHConnectionTestCase(unittest.TestCase):
             self.assertEqual(ssh_connection._stderr, "c")
             ssh_connection.disconnect()
 
+    def test_connect_auto_accept_host(self):
+        with patch("paramiko.SSHClient") as SSHClientMock:
+            client_mock = SSHClientMock.return_value
+            client_mock.exec_command.return_value = ["a", "b", "c"]
+            ssh_connection = SSHConnection(
+                known_hosts_file=self.known_hosts_file, auto_accept_host=True
+            )
+
+            ssh_connection.connect()
+            self.assertEqual(ssh_connection._stdin, "a")
+            self.assertEqual(ssh_connection._stdout, "b")
+            self.assertEqual(ssh_connection._stderr, "c")
+            ssh_connection.disconnect()
+
     def test_connect_unknown_host(self):
         ssh_connection = SSHConnection(
-            hostname="0.0.0.1", known_hosts_file=self.known_hosts_file
+            hostname="0.0.0.1",
+            known_hosts_file=self.known_hosts_file,
+            timeout=1.0,
         )
         with self.assertRaises(
             GvmError,
@@ -127,7 +148,9 @@ class SSHConnectionTestCase(unittest.TestCase):
             os.remove(self.known_hosts_file)
 
         ssh_connection = SSHConnection(
-            hostname="0.0.0.1", known_hosts_file=self.known_hosts_file
+            hostname="0.0.0.1",
+            known_hosts_file=self.known_hosts_file,
+            timeout=1.0,
         )
         with self.assertRaises(
             GvmError,
@@ -138,9 +161,9 @@ class SSHConnectionTestCase(unittest.TestCase):
         ):
             ssh_connection.connect()
 
+    @patch("builtins.print")
     @patch("builtins.input")
-    def test_connect_adding_and_save_hostkey(self, input_mock):
-
+    def test_connect_adding_and_save_hostkey(self, input_mock, _print_mock):
         key_io = StringIO(
             """-----BEGIN OPENSSH PRIVATE KEY-----
 b3BlbnNzaC1rZXktdjEAAAAABG5vbmUAAAAEbm9uZQAAAAAAAAABAAAAMwAAAAtzc2gtZW
@@ -188,9 +211,11 @@ FsAQI=
                 f"0.0.0.0 {key.get_name()} {key.get_base64()}\n",
             )
 
+    @patch("builtins.print")
     @patch("builtins.input")
-    def test_connect_adding_and_dont_save_hostkey(self, input_mock):
-
+    def test_connect_adding_and_dont_save_hostkey(
+        self, input_mock, _print_mock
+    ):
         key_io = StringIO(
             """-----BEGIN OPENSSH PRIVATE KEY-----
 b3BlbnNzaC1rZXktdjEAAAAABG5vbmUAAAAEbm9uZQAAAAAAAAABAAAAMwAAAAtzc2gtZW
@@ -241,7 +266,6 @@ FsAQI=
     @patch("builtins.input")
     @patch("sys.stdout", new_callable=StringIO)
     def test_connect_wrong_input(self, stdout_mock, input_mock):
-
         key_io = StringIO(
             """-----BEGIN OPENSSH PRIVATE KEY-----
 b3BlbnNzaC1rZXktdjEAAAAABG5vbmUAAAAEbm9uZQAAAAAAAAABAAAAMwAAAAtzc2gtZW
@@ -291,7 +315,6 @@ FsAQI=
 
     @patch("builtins.input")
     def test_user_denies_auth(self, input_mock):
-
         key_io = StringIO(
             """-----BEGIN OPENSSH PRIVATE KEY-----
 b3BlbnNzaC1rZXktdjEAAAAABG5vbmUAAAAEbm9uZQAAAAAAAAABAAAAMwAAAAtzc2gtZW
