@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -24,7 +24,7 @@ class GmpCloneCredentialTestMixin:
         self.gmp.clone_credential("a1")
 
         self.connection.send.has_been_called_with(
-            "<create_credential>" "<copy>a1</copy>" "</create_credential>"
+            "<create_credential><copy>a1</copy></create_credential>"
         )
 
     def test_missing_id(self):
