@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -21,14 +21,14 @@ from gvm.errors import GvmError
 
 class GmpDeleteGroupTestMixin:
     def test_delete(self):
-        self.gmp.delete_group('a1')
+        self.gmp.delete_group("a1")
 
         self.connection.send.has_been_called_with(
             '<delete_group group_id="a1" ultimate="0"/>'
         )
 
     def test_delete_ultimate(self):
-        self.gmp.delete_group('a1', ultimate=True)
+        self.gmp.delete_group("a1", ultimate=True)
 
         self.connection.send.has_been_called_with(
             '<delete_group group_id="a1" ultimate="1"/>'
@@ -39,4 +39,4 @@ class GmpDeleteGroupTestMixin:
             self.gmp.delete_group(None)
 
         with self.assertRaises(GvmError):
-            self.gmp.delete_group('')
+            self.gmp.delete_group("")
