@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -33,6 +33,19 @@ class GmpGetHostTestMixin:
             '<get_assets asset_id="a1" type="host"/>'
         )
 
+    def test_get_host_details(self):
+        self.gmp.get_host("a1", details=True)
+
+        self.connection.send.has_been_called_with(
+            '<get_assets asset_id="a1" type="host" details="1"/>'
+        )
+
+        self.gmp.get_host("a1", details=False)
+
+        self.connection.send.has_been_called_with(
+            '<get_assets asset_id="a1" type="host" details="0"/>'
+        )
+
     def test_get_host_missing_host_id(self):
         with self.assertRaises(RequiredArgument):
             self.gmp.get_host(
