@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -27,7 +27,7 @@ class GmpModifyNoteTestMixin:
         self.gmp.modify_note(note_id="n1", text="foo")
 
         self.connection.send.has_been_called_with(
-            '<modify_note note_id="n1">' "<text>foo</text>" "</modify_note>"
+            '<modify_note note_id="n1"><text>foo</text></modify_note>'
         )
 
     def test_modify_note_missing_note_id(self):
