@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -23,6 +23,19 @@ class GmpGetOperatingSystemsTestMixin:
 
         self.connection.send.has_been_called_with('<get_assets type="os"/>')
 
+    def test_get_operating_systems_details(self):
+        self.gmp.get_operating_systems(details=True)
+
+        self.connection.send.has_been_called_with(
+            '<get_assets type="os" details="1"/>'
+        )
+
+        self.gmp.get_operating_systems(details=False)
+
+        self.connection.send.has_been_called_with(
+            '<get_assets type="os" details="0"/>'
+        )
+
     def test_get_operating_systems_with_filter_string(self):
         self.gmp.get_operating_systems(filter_string="foo=bar")
 
