@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -24,7 +24,7 @@ class GmpClonePortListTestMixin:
         self.gmp.clone_port_list("a1")
 
         self.connection.send.has_been_called_with(
-            "<create_port_list>" "<copy>a1</copy>" "</create_port_list>"
+            "<create_port_list><copy>a1</copy></create_port_list>"
         )
 
     def test_missing_id(self):
