@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -21,7 +21,7 @@ from gvm.errors import RequiredArgument
 
 class GmpGetScanConfigPreferenceTestMixin:
     def test_get_preference(self):
-        self.gmp.get_scan_config_preference(name='foo')
+        self.gmp.get_scan_config_preference(name="foo")
 
         self.connection.send.has_been_called_with(
             '<get_preferences preference="foo"/>'
@@ -32,20 +32,20 @@ class GmpGetScanConfigPreferenceTestMixin:
             self.gmp.get_scan_config_preference(name=None)
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.get_scan_config_preference(name='')
+            self.gmp.get_scan_config_preference(name="")
 
         with self.assertRaises(RequiredArgument):
-            self.gmp.get_scan_config_preference('')
+            self.gmp.get_scan_config_preference("")
 
     def test_get_scan_config_preference_with_nvt_oid(self):
-        self.gmp.get_scan_config_preference(name='foo', nvt_oid='oid')
+        self.gmp.get_scan_config_preference(name="foo", nvt_oid="oid")
 
         self.connection.send.has_been_called_with(
             '<get_preferences preference="foo" nvt_oid="oid"/>'
         )
 
     def test_get_scan_config_preference_with_config_id(self):
-        self.gmp.get_scan_config_preference(name='foo', config_id='c1')
+        self.gmp.get_scan_config_preference(name="foo", config_id="c1")
 
         self.connection.send.has_been_called_with(
             '<get_preferences preference="foo" config_id="c1"/>'
