@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -21,17 +21,17 @@ class GmpGetScanConfigPreferencesTestMixin:
     def test_get_scan_config_preferences(self):
         self.gmp.get_scan_config_preferences()
 
-        self.connection.send.has_been_called_with('<get_preferences/>')
+        self.connection.send.has_been_called_with("<get_preferences/>")
 
     def test_get_scan_config_preferences_with_nvt_oid(self):
-        self.gmp.get_scan_config_preferences(nvt_oid='oid')
+        self.gmp.get_scan_config_preferences(nvt_oid="oid")
 
         self.connection.send.has_been_called_with(
             '<get_preferences nvt_oid="oid"/>'
         )
 
     def test_get_scan_config_preferences_with_config_id(self):
-        self.gmp.get_scan_config_preferences(config_id='c1')
+        self.gmp.get_scan_config_preferences(config_id="c1")
 
         self.connection.send.has_been_called_with(
             '<get_preferences config_id="c1"/>'
