@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -42,3 +42,23 @@ class GmpGetNvtTestMixin:
 
         with self.assertRaises(RequiredArgument):
             self.gmp.get_nvt(nvt_id=None)
+
+    def test_get_extended_nvt_with_nvt_oid(self):
+        self.gmp.get_nvt(extended=True, nvt_id="nvt_oid")
+
+        self.connection.send.has_been_called_with(
+            (
+                '<get_nvts nvt_oid="nvt_oid" details="1" '
+                'preferences="1" preference_count="1"/>'
+            )
+        )
+
+    def test_get_extended_nvt_missing_nvt_oid(self):
+        with self.assertRaises(RequiredArgument):
+            self.gmp.get_nvt(extended=True, nvt_id=None)
+
+        with self.assertRaises(RequiredArgument):
+            self.gmp.get_nvt(extended=True, nvt_id="")
+
+        with self.assertRaises(RequiredArgument):
+            self.gmp.get_nvt("", extended=True)
