@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2019-2022 Greenbone Networks GmbH
+# Copyright (C) 2019-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -24,13 +24,13 @@ class GmpCloneTicketTestMixin:
         self.gmp.clone_ticket("t1")
 
         self.connection.send.has_been_called_with(
-            "<create_ticket>" "<copy>t1</copy>" "</create_ticket>"
+            "<create_ticket><copy>t1</copy></create_ticket>"
         )
 
         self.gmp.clone_ticket(ticket_id="t1")
 
         self.connection.send.has_been_called_with(
-            "<create_ticket>" "<copy>t1</copy>" "</create_ticket>"
+            "<create_ticket><copy>t1</copy></create_ticket>"
         )
 
     def test_missing_id(self):
