@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -23,28 +23,27 @@ from . import Gmpv224TestCase
 
 class GmpWithStatementTestMixin:
     def test_types(self):
-
         with self.gmp:
             # Test that the values are equal
-            self.assertEquals(
+            self.assertEqual(
                 self.gmp.types.AlertEvent.TASK_RUN_STATUS_CHANGED.value,
                 "Task run status changed",
             )
-            self.assertEquals(
+            self.assertEqual(
                 self.gmp.types.PermissionSubjectType.USER.value, "user"
             )
-            self.assertEquals(
+            self.assertEqual(
                 self.gmp.types.HostsOrdering.RANDOM.value, "random"
             )
 
             # Test usability of from_string
-            self.assertEquals(
+            self.assertEqual(
                 self.gmp.types.HostsOrdering.from_string("reverse"),
                 self.gmp.types.HostsOrdering.REVERSE,
             )
 
             # Test, that the Enum class types are equal
-            self.assertEquals(self.gmp.types.HostsOrdering, HostsOrdering)
+            self.assertEqual(self.gmp.types.HostsOrdering, HostsOrdering)
 
 
 class Gmpv224WithStatementTestCase(GmpWithStatementTestMixin, Gmpv224TestCase):
